@charset "utf-8";
/* CSS Document */
* {margin:0;
   padding:0;
}

body {background:#f2f2f2;
}

.main{
width:615px;
height:auto;
background-color:#FFFF66;}

/*.slides{height:350px;
}*/


.slides{width:100%;
}

.slides img{width:100%;
}

.slidesjs-pagination{

background:#424242;
list-style:none;
overflow:hidden;
}



.slidesjs-pagination li{
float:left;
}

.slidesjs-pagination li a {
	display:block;
	padding:5px 5px;/*10 20*/
	color:#fff;
	text-decoration:none;
}

.slidesjs-pagination li a:hover{
background:#000;
}

.slides .active{background:#000;
}

.slidesjs-navigation {

background:#000;
color:#fff;
text-decoration:none;
display:inline-block;
padding:5px 5px;/*10 10*/
float:right;
}






